# -*- coding: utf-8 -*-

import zeep

# Webová služba pro práci s dotacemi
class Grants(object):
    __module__ = 'skautis'

    def __init__(self, test):
        if test:
            self._client = zeep.Client('https://test-is.skaut.cz/JunakWebservice/Grants.asmx?wsdl')
        else:
            self._client = zeep.Client('https://is.skaut.cz/JunakWebservice/Grants.asmx?wsdl')

    # Zadat vyjádření revizní komise
    def GrantUpdateCommitteeNote(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateCommitteeNote({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Upravit hodnotu celkové dotace žádosti o dotaci
    def GrantUpdateAmount(self, ID_Login, ID, Amount, MaximumCostsRatio, GrantConditions=None):
        return self._client.service.GrantUpdateAmount({"ID_Login": ID_Login, "ID": ID, "Amount": Amount, "MaximumCostsRatio": MaximumCostsRatio, "GrantConditions": GrantConditions})

    # Potvrdit rozhodnutí o žádosti o dotaci
    def GrantUpdateApproveDecision(self, ID_Login, ID):
        return self._client.service.GrantUpdateApproveDecision({"ID_Login": ID_Login, "ID": ID})

    # Schválit žádost o dotaci
    def GrantUpdateApprove(self, ID_Login, ID):
        return self._client.service.GrantUpdateApprove({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail zprávy dotace
    def MessageDetail(self, ID_Login, ID):
        return self._client.service.MessageDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit zprávu dotace
    def MessageInsert(self, ID_Login, ID, Created, Sent, ID_Person, GrantCount, Text=None, Person=None, Grants=None):
        return self._client.service.MessageInsert({"ID_Login": ID_Login, "ID": ID, "Created": Created, "Sent": Sent, "ID_Person": ID_Person, "GrantCount": GrantCount, "Text": Text, "Person": Person, "Grants": Grants})

    # Odeslat zprávu dotace
    def MessageUpdateSend(self, ID_Login, ID, Created, Sent, ID_Person, GrantCount, Text=None, Person=None, Grants=None):
        return self._client.service.MessageUpdateSend({"ID_Login": ID_Login, "ID": ID, "Created": Created, "Sent": Sent, "ID_Person": ID_Person, "GrantCount": GrantCount, "Text": Text, "Person": Person, "Grants": Grants})

    # Upravit zprávu dotace
    def MessageUpdate(self, ID_Login, ID, Created, Sent, ID_Person, GrantCount, Text=None, Person=None, Grants=None):
        return self._client.service.MessageUpdate({"ID_Login": ID_Login, "ID": ID, "Created": Created, "Sent": Sent, "ID_Person": ID_Person, "GrantCount": GrantCount, "Text": Text, "Person": Person, "Grants": Grants})

    # Načíst seznam účastí na kurzu vzdělávací akce
    def ParticipantCourseTermAll(self, ID_Login, ID_Grant, ID_EventEducationTermArray=None):
        return self._client.service.ParticipantCourseTermAll({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID_EventEducationTermArray": ID_EventEducationTermArray})

    # Upravit ucast na kurzu
    def ParticipantCourseTermUpdate(self, ID_Login, ID_ParticipantEducation, ParticipantTermDays=None):
        return self._client.service.ParticipantCourseTermUpdate({"ID_Login": ID_Login, "ID_ParticipantEducation": ID_ParticipantEducation, "ParticipantTermDays": ParticipantTermDays})

    # Načíst seznam položek rozpočtu
    def StatementAll(self, ID_Login, ID_EventEducation, ID_Grant, ID, IsRevenue, IsBudget, Year):
        return self._client.service.StatementAll({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "ID_Grant": ID_Grant, "ID": ID, "IsRevenue": IsRevenue, "IsBudget": IsBudget, "Year": Year})

    # Smazat položku rozpočtu
    def StatementDelete(self, ID_Login, ID, ID_Event, ID_Grant, ID_EventEducation, IsEstimate, Ammount, IsRevenue, IsBudget, ID_Unit, Year, IsRevenueCustom, ShowOverview, Event=None, ID_StatementType=None, StatementType=None, StatementTypeCustom=None, Unit=None, RegistrationNumber=None, Note=None):
        return self._client.service.StatementDelete({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_Grant": ID_Grant, "ID_EventEducation": ID_EventEducation, "IsEstimate": IsEstimate, "Ammount": Ammount, "IsRevenue": IsRevenue, "IsBudget": IsBudget, "ID_Unit": ID_Unit, "Year": Year, "IsRevenueCustom": IsRevenueCustom, "ShowOverview": ShowOverview, "Event": Event, "ID_StatementType": ID_StatementType, "StatementType": StatementType, "StatementTypeCustom": StatementTypeCustom, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Note": Note})

    # Založit položku rozpočtu
    def StatementInsert(self, ID_Login, ID, ID_Event, ID_Grant, ID_EventEducation, IsEstimate, Ammount, IsRevenue, IsBudget, ID_Unit, Year, IsRevenueCustom, ShowOverview, Event=None, ID_StatementType=None, StatementType=None, StatementTypeCustom=None, Unit=None, RegistrationNumber=None, Note=None):
        return self._client.service.StatementInsert({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_Grant": ID_Grant, "ID_EventEducation": ID_EventEducation, "IsEstimate": IsEstimate, "Ammount": Ammount, "IsRevenue": IsRevenue, "IsBudget": IsBudget, "ID_Unit": ID_Unit, "Year": Year, "IsRevenueCustom": IsRevenueCustom, "ShowOverview": ShowOverview, "Event": Event, "ID_StatementType": ID_StatementType, "StatementType": StatementType, "StatementTypeCustom": StatementTypeCustom, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Note": Note})

    # Synchronizovat předpokládaný a finální rozpočet
    def StatementOtherSync(self, ID_Login, ID):
        return self._client.service.StatementOtherSync({"ID_Login": ID_Login, "ID": ID})

    # Upravit položku rozpočtu
    def StatementUpdate(self, ID_Login, ID, ID_Event, ID_Grant, ID_EventEducation, IsEstimate, Ammount, IsRevenue, IsBudget, ID_Unit, Year, IsRevenueCustom, ShowOverview, Event=None, ID_StatementType=None, StatementType=None, StatementTypeCustom=None, Unit=None, RegistrationNumber=None, Note=None):
        return self._client.service.StatementUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_Grant": ID_Grant, "ID_EventEducation": ID_EventEducation, "IsEstimate": IsEstimate, "Ammount": Ammount, "IsRevenue": IsRevenue, "IsBudget": IsBudget, "ID_Unit": ID_Unit, "Year": Year, "IsRevenueCustom": IsRevenueCustom, "ShowOverview": ShowOverview, "Event": Event, "ID_StatementType": ID_StatementType, "StatementType": StatementType, "StatementTypeCustom": StatementTypeCustom, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Note": Note})

    # Načíst seznam typů zálohy
    def GrantAdvanceTypeAll(self, ID_Login, ID=None, ID_GrantType=None, DisplayName=None):
        return self._client.service.GrantAdvanceTypeAll({"ID_Login": ID_Login, "ID": ID, "ID_GrantType": ID_GrantType, "DisplayName": DisplayName})

    # Načíst detail typu zálohy
    def GrantAdvanceTypeDetail(self, ID_Login, ID=None):
        return self._client.service.GrantAdvanceTypeDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam žádostí o dotaci
    def GrantAll(self, ID_Login, ID, ID_Event, ID_Unit, ID_GrantType=None, ID_GrantAdvanceType=None, ID_GrantState=None):
        return self._client.service.GrantAll({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_Unit": ID_Unit, "ID_GrantType": ID_GrantType, "ID_GrantAdvanceType": ID_GrantAdvanceType, "ID_GrantState": ID_GrantState})

    # Smazat žádost o dotaci
    def GrantDelete(self, ID_Login, ID):
        return self._client.service.GrantDelete({"ID_Login": ID_Login, "ID": ID})

    # Odevzdat žádost o dotaci k posouzení
    def GrantUpdateApply(self, ID_Login, ID):
        return self._client.service.GrantUpdateApply({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail žádosti o dotaci
    def GrantDetailEventEducation(self, ID_Login, ID_EventEducation, Year):
        return self._client.service.GrantDetailEventEducation({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "Year": Year})

    # Načíst detail žádosti o dotaci
    def GrantDetail(self, ID_Login, ID, Year):
        return self._client.service.GrantDetail({"ID_Login": ID_Login, "ID": ID, "Year": Year})

    # Načíst seznam stavů žádosti o dotaci
    def GrantGrantStateAll(self, ID_Login, ID_Grant, ID, ID_User, ID_GrantState=None):
        return self._client.service.GrantGrantStateAll({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID": ID, "ID_User": ID_User, "ID_GrantState": ID_GrantState})

    # Smazat stav žádosti o dotaci
    def GrantGrantStateDelete(self, ID_Login, ID):
        return self._client.service.GrantGrantStateDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit stav žádosti o dotaci
    def GrantGrantStateInsert(self, ID_Login, ID, ID_Grant, Changed, IsActual, ID_User, ID_GrantState=None, GrantState=None, ChangeNote=None):
        return self._client.service.GrantGrantStateInsert({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "Changed": Changed, "IsActual": IsActual, "ID_User": ID_User, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ChangeNote": ChangeNote})

    # Založit žádost o dotaci
    def GrantInsert(self, ID_Login, ID_EventEducation, ID_Event, ID_Unit, ID_EventEducationCourse, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, CreateRemaining, RealizationFrom, RealizationTo, ID_GrantType=None, ProjectName=None, NoteLeader=None, NoteEconomist=None, NoteResponsible=None):
        return self._client.service.GrantInsert({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "ID_Event": ID_Event, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "CreateRemaining": CreateRemaining, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_GrantType": ID_GrantType, "ProjectName": ProjectName, "NoteLeader": NoteLeader, "NoteEconomist": NoteEconomist, "NoteResponsible": NoteResponsible})

    # Načíst seznam stavů žádosti o dotaci
    def GrantStateAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.GrantStateAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst detail stavu žádosti o dotaci
    def GrantStateDetail(self, ID_Login, ID=None):
        return self._client.service.GrantStateDetail({"ID_Login": ID_Login, "ID": ID})

    # Načíst seznam typů dotace
    def GrantTypeAll(self, ID_Login, ForUnit, ForEvent, ID=None, DisplayName=None):
        return self._client.service.GrantTypeAll({"ID_Login": ID_Login, "ForUnit": ForUnit, "ForEvent": ForEvent, "ID": ID, "DisplayName": DisplayName})

    # Načíst detail typu dotace
    def GrantTypeDetail(self, ID_Login, ID=None):
        return self._client.service.GrantTypeDetail({"ID_Login": ID_Login, "ID": ID})

    # Upravit žádost o dotaci
    def GrantUpdate(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Načíst seznam období zálohy na dotaci
    def AdvancePeriodAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.AdvancePeriodAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam stavů zálohy
    def AdvanceStateAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.AdvanceStateAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst seznam typů přílohy
    def AttachmentTypeAll(self, ID_Application, ID_Login, ID=None, DisplayName=None, ID_GrantType=None):
        return self._client.service.AttachmentTypeAll({"ID_Application": ID_Application, "ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName, "ID_GrantType": ID_GrantType})

    # Načíst seznam částek financování žádosti o dotaci
    def FinanceAll(self, ID_Login, ID_Grant, ID, IsRevenue, IsReal, ID_FinanceType=None):
        return self._client.service.FinanceAll({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID": ID, "IsRevenue": IsRevenue, "IsReal": IsReal, "ID_FinanceType": ID_FinanceType})

    # Smazat částku financování žádosti o dotaci
    def FinanceDelete(self, ID_Login, ID, ID_Grant, Amount, AmountReal, IsRevenue, IsRealAmount, ID_FinanceType=None, FinanceType=None, FinanceTypeCustom=None, FinanceTypeDisplay=None):
        return self._client.service.FinanceDelete({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "Amount": Amount, "AmountReal": AmountReal, "IsRevenue": IsRevenue, "IsRealAmount": IsRealAmount, "ID_FinanceType": ID_FinanceType, "FinanceType": FinanceType, "FinanceTypeCustom": FinanceTypeCustom, "FinanceTypeDisplay": FinanceTypeDisplay})

    # Načíst detail částky financování žádosti o dotaci
    def FinanceDetail(self, ID_Login, ID):
        return self._client.service.FinanceDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit částku financování žádosti o dotaci
    def FinanceInsert(self, ID_Login, ID, ID_Grant, Amount, AmountReal, IsRevenue, IsRealAmount, ID_FinanceType=None, FinanceType=None, FinanceTypeCustom=None, FinanceTypeDisplay=None):
        return self._client.service.FinanceInsert({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "Amount": Amount, "AmountReal": AmountReal, "IsRevenue": IsRevenue, "IsRealAmount": IsRealAmount, "ID_FinanceType": ID_FinanceType, "FinanceType": FinanceType, "FinanceTypeCustom": FinanceTypeCustom, "FinanceTypeDisplay": FinanceTypeDisplay})

    # Upravit částku financování žádosti o dotaci
    def FinanceUpdate(self, ID_Login, ID, ID_Grant, Amount, AmountReal, IsRevenue, IsRealAmount, ID_FinanceType=None, FinanceType=None, FinanceTypeCustom=None, FinanceTypeDisplay=None):
        return self._client.service.FinanceUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "Amount": Amount, "AmountReal": AmountReal, "IsRevenue": IsRevenue, "IsRealAmount": IsRealAmount, "ID_FinanceType": ID_FinanceType, "FinanceType": FinanceType, "FinanceTypeCustom": FinanceTypeCustom, "FinanceTypeDisplay": FinanceTypeDisplay})

    # Načíst seznam dotací a jejich záloh
    def GrantAdvanceAllPayments(self, ID_Login, ID, ID_Grant, ID_Unit, ID_Event, ID_EventEducationTerm, Year, DaysAhead, ID_GrantAdvanceType=None, ID_GrantState=None, ID_GrantType=None, ID_State=None):
        return self._client.service.GrantAdvanceAllPayments({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_Unit": ID_Unit, "ID_Event": ID_Event, "ID_EventEducationTerm": ID_EventEducationTerm, "Year": Year, "DaysAhead": DaysAhead, "ID_GrantAdvanceType": ID_GrantAdvanceType, "ID_GrantState": ID_GrantState, "ID_GrantType": ID_GrantType, "ID_State": ID_State})

    # Načíst seznam záloh na dotaci
    def GrantAdvanceCheck(self, ID_Login, Year):
        return self._client.service.GrantAdvanceCheck({"ID_Login": ID_Login, "Year": Year})

    # Načíst seznam záloh na dotaci
    def GrantAdvanceAll(self, ID_Login, ID, ID_Grant, ID_EventEducationTerm):
        return self._client.service.GrantAdvanceAll({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_EventEducationTerm": ID_EventEducationTerm})

    # Smazat zálohu na dotaci
    def GrantAdvanceDelete(self, ID_Login, ID, ID_Grant, ID_EventEducationTerm, Amount, PaidDate, IssueDate, InsertedDate, Year, RequestedAmount, TermDays, ID_Event, ID_EventEducation, ID_Unit, ID_GrantProject, EventEducationTerm=None, ID_AdvancePeriod=None, AdvancePeriod=None, ID_AdvanceState=None, AdvanceState=None, Note=None, Key=None, MoneyNumber=None, Unit=None, RegistrationNumber=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, GrantAdvanceTypeShort=None, GrantAdvanceTypeNote=None, AdvanceStateShort=None, ID_GrantType=None, GrantType=None, DisplayName=None):
        return self._client.service.GrantAdvanceDelete({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_EventEducationTerm": ID_EventEducationTerm, "Amount": Amount, "PaidDate": PaidDate, "IssueDate": IssueDate, "InsertedDate": InsertedDate, "Year": Year, "RequestedAmount": RequestedAmount, "TermDays": TermDays, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "ID_Unit": ID_Unit, "ID_GrantProject": ID_GrantProject, "EventEducationTerm": EventEducationTerm, "ID_AdvancePeriod": ID_AdvancePeriod, "AdvancePeriod": AdvancePeriod, "ID_AdvanceState": ID_AdvanceState, "AdvanceState": AdvanceState, "Note": Note, "Key": Key, "MoneyNumber": MoneyNumber, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "GrantAdvanceTypeShort": GrantAdvanceTypeShort, "GrantAdvanceTypeNote": GrantAdvanceTypeNote, "AdvanceStateShort": AdvanceStateShort, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "DisplayName": DisplayName})

    # Načíst detail zálohy na dotaci
    def GrantAdvanceDetail(self, ID_Login, ID):
        return self._client.service.GrantAdvanceDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit zálohu na dotaci
    def GrantAdvanceInsert(self, ID_Login, ID, ID_Grant, ID_EventEducationTerm, Amount, PaidDate, IssueDate, InsertedDate, Year, RequestedAmount, TermDays, ID_Event, ID_EventEducation, ID_Unit, ID_GrantProject, EventEducationTerm=None, ID_AdvancePeriod=None, AdvancePeriod=None, ID_AdvanceState=None, AdvanceState=None, Note=None, Key=None, MoneyNumber=None, Unit=None, RegistrationNumber=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, GrantAdvanceTypeShort=None, GrantAdvanceTypeNote=None, AdvanceStateShort=None, ID_GrantType=None, GrantType=None, DisplayName=None):
        return self._client.service.GrantAdvanceInsert({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_EventEducationTerm": ID_EventEducationTerm, "Amount": Amount, "PaidDate": PaidDate, "IssueDate": IssueDate, "InsertedDate": InsertedDate, "Year": Year, "RequestedAmount": RequestedAmount, "TermDays": TermDays, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "ID_Unit": ID_Unit, "ID_GrantProject": ID_GrantProject, "EventEducationTerm": EventEducationTerm, "ID_AdvancePeriod": ID_AdvancePeriod, "AdvancePeriod": AdvancePeriod, "ID_AdvanceState": ID_AdvanceState, "AdvanceState": AdvanceState, "Note": Note, "Key": Key, "MoneyNumber": MoneyNumber, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "GrantAdvanceTypeShort": GrantAdvanceTypeShort, "GrantAdvanceTypeNote": GrantAdvanceTypeNote, "AdvanceStateShort": AdvanceStateShort, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "DisplayName": DisplayName})

    # Upravit zálohu na dotaci
    def GrantAdvanceUpdatePayments(self, ID_Login, ID, ID_Grant, ID_EventEducationTerm, Amount, PaidDate, IssueDate, InsertedDate, Year, RequestedAmount, TermDays, ID_Event, ID_EventEducation, ID_Unit, ID_GrantProject, EventEducationTerm=None, ID_AdvancePeriod=None, AdvancePeriod=None, ID_AdvanceState=None, AdvanceState=None, Note=None, Key=None, MoneyNumber=None, Unit=None, RegistrationNumber=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, GrantAdvanceTypeShort=None, GrantAdvanceTypeNote=None, AdvanceStateShort=None, ID_GrantType=None, GrantType=None, DisplayName=None):
        return self._client.service.GrantAdvanceUpdatePayments({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_EventEducationTerm": ID_EventEducationTerm, "Amount": Amount, "PaidDate": PaidDate, "IssueDate": IssueDate, "InsertedDate": InsertedDate, "Year": Year, "RequestedAmount": RequestedAmount, "TermDays": TermDays, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "ID_Unit": ID_Unit, "ID_GrantProject": ID_GrantProject, "EventEducationTerm": EventEducationTerm, "ID_AdvancePeriod": ID_AdvancePeriod, "AdvancePeriod": AdvancePeriod, "ID_AdvanceState": ID_AdvanceState, "AdvanceState": AdvanceState, "Note": Note, "Key": Key, "MoneyNumber": MoneyNumber, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "GrantAdvanceTypeShort": GrantAdvanceTypeShort, "GrantAdvanceTypeNote": GrantAdvanceTypeNote, "AdvanceStateShort": AdvanceStateShort, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "DisplayName": DisplayName})

    # Upravit zálohu na dotaci
    def GrantAdvanceUpdate(self, ID_Login, ID, ID_Grant, ID_EventEducationTerm, Amount, PaidDate, IssueDate, InsertedDate, Year, RequestedAmount, TermDays, ID_Event, ID_EventEducation, ID_Unit, ID_GrantProject, EventEducationTerm=None, ID_AdvancePeriod=None, AdvancePeriod=None, ID_AdvanceState=None, AdvanceState=None, Note=None, Key=None, MoneyNumber=None, Unit=None, RegistrationNumber=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, GrantAdvanceTypeShort=None, GrantAdvanceTypeNote=None, AdvanceStateShort=None, ID_GrantType=None, GrantType=None, DisplayName=None):
        return self._client.service.GrantAdvanceUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_EventEducationTerm": ID_EventEducationTerm, "Amount": Amount, "PaidDate": PaidDate, "IssueDate": IssueDate, "InsertedDate": InsertedDate, "Year": Year, "RequestedAmount": RequestedAmount, "TermDays": TermDays, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "ID_Unit": ID_Unit, "ID_GrantProject": ID_GrantProject, "EventEducationTerm": EventEducationTerm, "ID_AdvancePeriod": ID_AdvancePeriod, "AdvancePeriod": AdvancePeriod, "ID_AdvanceState": ID_AdvanceState, "AdvanceState": AdvanceState, "Note": Note, "Key": Key, "MoneyNumber": MoneyNumber, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "GrantAdvanceTypeShort": GrantAdvanceTypeShort, "GrantAdvanceTypeNote": GrantAdvanceTypeNote, "AdvanceStateShort": AdvanceStateShort, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "DisplayName": DisplayName})

    # Načíst seznam záloh na dotaci
    def GrantAdvanceUsingAllYear(self, ID_Login):
        return self._client.service.GrantAdvanceUsingAllYear({"ID_Login": ID_Login})

    # Ústřední přehled žádostí o dotaci
    def GrantAllHeadquartersBuilding(self, ID_Login, ID, Year, ID_GrantState=None):
        return self._client.service.GrantAllHeadquartersBuilding({"ID_Login": ID_Login, "ID": ID, "Year": Year, "ID_GrantState": ID_GrantState})

    # Načíst seznam žádostí o dotaci pro zprávu dotace
    def GrantAllMessage(self, ID_Login, ID_Message):
        return self._client.service.GrantAllMessage({"ID_Login": ID_Login, "ID_Message": ID_Message})

    # Ústřední přehled vyúčtování žádostí o dotaci
    def GrantAllAccount(self, ID_Login, Year, ID_GrantType=None, ID_GrantState=None):
        return self._client.service.GrantAllAccount({"ID_Login": ID_Login, "Year": Year, "ID_GrantType": ID_GrantType, "ID_GrantState": ID_GrantState})

    # Ústřední přehled žádostí o dotaci
    def GrantAllHeadquarters(self, ID_Login, ID, Year, ID_GrantType=None, HeadquartersNote=None):
        return self._client.service.GrantAllHeadquarters({"ID_Login": ID_Login, "ID": ID, "Year": Year, "ID_GrantType": ID_GrantType, "HeadquartersNote": HeadquartersNote})

    # Načíst seznam záloh na dotaci
    def GrantAdvanceUsingAll(self, ID_Login, ID, Year):
        return self._client.service.GrantAdvanceUsingAll({"ID_Login": ID_Login, "ID": ID, "Year": Year})

    # Založit čerpání dotace
    def GrantAdvanceUsingInsert(self, ID_Login):
        return self._client.service.GrantAdvanceUsingInsert({"ID_Login": ID_Login})

    # Smazat projekt
    def GrantProjectUniversalDelete(self, ID_Login, ID):
        return self._client.service.GrantProjectUniversalDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail projektu
    def GrantProjectUniversalDetail(self, ID_Login, ID, ID_Grant):
        return self._client.service.GrantProjectUniversalDetail({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant})

    # Založit projekt
    def GrantProjectUniversalInsertGrant(self, ID_Login, ID, ID_User, ID_Grant, Goal=None, ProjectCharacteristic=None, Description=None, Information=None, TargetGroup=None):
        return self._client.service.GrantProjectUniversalInsertGrant({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "Goal": Goal, "ProjectCharacteristic": ProjectCharacteristic, "Description": Description, "Information": Information, "TargetGroup": TargetGroup})

    # Upravit projekt
    def GrantProjectUniversalUpdate(self, ID_Login, ID, ID_User, ID_Grant, Goal=None, ProjectCharacteristic=None, Description=None, Information=None, TargetGroup=None):
        return self._client.service.GrantProjectUniversalUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "Goal": Goal, "ProjectCharacteristic": ProjectCharacteristic, "Description": Description, "Information": Information, "TargetGroup": TargetGroup})

    # Ústřední přehled žádostí o dotaci
    def GrantReportHadquartersUniversal(self, ID_Login, ID, Year, ID_GrantState=None):
        return self._client.service.GrantReportHadquartersUniversal({"ID_Login": ID_Login, "ID": ID, "Year": Year, "ID_GrantState": ID_GrantState})

    # Ústřední přehled žádostí o dotaci
    def GrantReportHadquartersBuilding(self, ID_Login, ID, Year, ID_GrantState=None):
        return self._client.service.GrantReportHadquartersBuilding({"ID_Login": ID_Login, "ID": ID, "Year": Year, "ID_GrantState": ID_GrantState})

    # Ústřední přehled žádostí o dotaci
    def GrantReportHeadquartersUnorganizedYouth(self, ID_Login, ID, Year, ID_GrantState=None):
        return self._client.service.GrantReportHeadquartersUnorganizedYouth({"ID_Login": ID_Login, "ID": ID, "Year": Year, "ID_GrantState": ID_GrantState})

    # Ústřední přehled žádostí o dotaci
    def GrantAllHeadquartersUnorganizedYouth(self, ID_Login, ID, Year, ID_GrantState=None):
        return self._client.service.GrantAllHeadquartersUnorganizedYouth({"ID_Login": ID_Login, "ID": ID, "Year": Year, "ID_GrantState": ID_GrantState})

    # Načíst seznam dílčích akcí pro neorg. mládež
    def GrantEventAll(self, ID_Login, ID, ID_Grant, IsEstimation, DisplayName=None):
        return self._client.service.GrantEventAll({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "IsEstimation": IsEstimation, "DisplayName": DisplayName})

    # Smazat dílčí akci pro neorg. mládež
    def GrantEventDelete(self, ID_Login, ID, ID_User, ID_Grant, Count, Days, ChildrenCount, YoungCount, OtherCount, PersonDays, IsEstimation, IsCustomDays, DisplayName=None, Description=None, Place=None):
        return self._client.service.GrantEventDelete({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "Count": Count, "Days": Days, "ChildrenCount": ChildrenCount, "YoungCount": YoungCount, "OtherCount": OtherCount, "PersonDays": PersonDays, "IsEstimation": IsEstimation, "IsCustomDays": IsCustomDays, "DisplayName": DisplayName, "Description": Description, "Place": Place})

    # Zaslat upomínky pro potvrzení rozhodnutí
    def GrantEventEducationReminder(self, ID_Login):
        return self._client.service.GrantEventEducationReminder({"ID_Login": ID_Login})

    # Načíst zjednodušený detail žádosti o dotaci
    def GrantDetailSimple(self, ID_Login, ID, Year):
        return self._client.service.GrantDetailSimple({"ID_Login": ID_Login, "ID": ID, "Year": Year})

    # Načíst částky a počty pro jednotlivé kurzy VzA žádající o dotaci
    def GrantDetailParticipationOverview(self, ID_Login, ID_Grant, ID_Event, Year, IsEstimation):
        return self._client.service.GrantDetailParticipationOverview({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID_Event": ID_Event, "Year": Year, "IsEstimation": IsEstimation})

    # Načíst seznam příloh žádosti o dotaci
    def GrantAttachmentAllAttachmentType(self, ID_Login, ID_Grant, ID, ID_User, IsReal, ID_FileType=None, ID_AttachmentType=None):
        return self._client.service.GrantAttachmentAllAttachmentType({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID": ID, "ID_User": ID_User, "IsReal": IsReal, "ID_FileType": ID_FileType, "ID_AttachmentType": ID_AttachmentType})

    # Načíst detail přílohy žádosti o dotaci
    def GrantAttachmentDetailGrant(self, ID_Login, ID_Grant, ID, ID_AttachmentType=None):
        return self._client.service.GrantAttachmentDetailGrant({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID": ID, "ID_AttachmentType": ID_AttachmentType})

    # Upravit přílohu žádosti o dotaci
    def GrantAttachmentUpdateGrant(self, ID_Login, ID, IsReal, ID_Grant, ID_User, ID_Person, Date, Size, ID_TempFile, ID_GrantAttachment, IsAttached, IsCentralInsurance, IsDeposited, DepositYear, ID_Document, ID_DocumentBackup, Person=None, Description=None, FileName=None, ID_FileType=None, FileType=None, Extension=None, Hash=None, FileNameExtension=None, TempFile=None, IconPath=None, ID_AttachmentType=None, AttachmentType=None, BackupFileName=None, BackupExtension=None, ID_FileTypeBackup=None, BackupFileType=None, BackupIconPath=None, Note=None, Code=None, ID_GrantType=None, GrantType=None, Help=None, DisplayName=None):
        return self._client.service.GrantAttachmentUpdateGrant({"ID_Login": ID_Login, "ID": ID, "IsReal": IsReal, "ID_Grant": ID_Grant, "ID_User": ID_User, "ID_Person": ID_Person, "Date": Date, "Size": Size, "ID_TempFile": ID_TempFile, "ID_GrantAttachment": ID_GrantAttachment, "IsAttached": IsAttached, "IsCentralInsurance": IsCentralInsurance, "IsDeposited": IsDeposited, "DepositYear": DepositYear, "ID_Document": ID_Document, "ID_DocumentBackup": ID_DocumentBackup, "Person": Person, "Description": Description, "FileName": FileName, "ID_FileType": ID_FileType, "FileType": FileType, "Extension": Extension, "Hash": Hash, "FileNameExtension": FileNameExtension, "TempFile": TempFile, "IconPath": IconPath, "ID_AttachmentType": ID_AttachmentType, "AttachmentType": AttachmentType, "BackupFileName": BackupFileName, "BackupExtension": BackupExtension, "ID_FileTypeBackup": ID_FileTypeBackup, "BackupFileType": BackupFileType, "BackupIconPath": BackupIconPath, "Note": Note, "Code": Code, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Help": Help, "DisplayName": DisplayName})

    # Načíst roky konání vzdělávací akce
    def GrantDetailYears(self, ID_Login, ID_Application, ID_EventEducation, ID_Grant):
        return self._client.service.GrantDetailYears({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID_EventEducation": ID_EventEducation, "ID_Grant": ID_Grant})

    # Načíst detail o dotaci a rozpočtu
    def GrantDetailGrantStatement(self, ID_Login, ID_Grant, ID_EventEducation, Year):
        return self._client.service.GrantDetailGrantStatement({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID_EventEducation": ID_EventEducation, "Year": Year})

    # Načíst seznam typů data
    def DateTypeAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.DateTypeAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Přehled žádostí o dotaci
    def GrantAllSummary(self, ID_Login, Year):
        return self._client.service.GrantAllSummary({"ID_Login": ID_Login, "Year": Year})

    # Ústřední přehled žádostí o dotaci
    def GrantAllHeadquartersUniversal(self, ID_Login, ID, Year, ID_GrantState=None):
        return self._client.service.GrantAllHeadquartersUniversal({"ID_Login": ID_Login, "ID": ID, "Year": Year, "ID_GrantState": ID_GrantState})

    # Přehled žádostí o dotaci pro OJ
    def GrantAllUnitSummary(self, ID_Login, Year, ID_Unit, ShowSubordinateUnits, ID_GrantState=None, ID_GrantType=None):
        return self._client.service.GrantAllUnitSummary({"ID_Login": ID_Login, "Year": Year, "ID_Unit": ID_Unit, "ShowSubordinateUnits": ShowSubordinateUnits, "ID_GrantState": ID_GrantState, "ID_GrantType": ID_GrantType})

    # Načíst seznam částek na osoboden
    def GrantAmountAll(self, ID_Login, ID_Grant, ID, ID_EventEducationType, Year):
        return self._client.service.GrantAmountAll({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID": ID, "ID_EventEducationType": ID_EventEducationType, "Year": Year})

    # Načíst seznam přednastavených částky dotace
    def GrantAmountDefaultAll(self, ID_Login, ID, ID_EventEducationType):
        return self._client.service.GrantAmountDefaultAll({"ID_Login": ID_Login, "ID": ID, "ID_EventEducationType": ID_EventEducationType})

    # Načíst detail přednastavené částky dotace
    def GrantAmountDefaultDetail(self, ID_Login, ID):
        return self._client.service.GrantAmountDefaultDetail({"ID_Login": ID_Login, "ID": ID})

    # Smazat částky na osoboden pro žádost o dotaci
    def GrantAmountDeleteGrant(self, ID_Login, ID_Grant):
        return self._client.service.GrantAmountDeleteGrant({"ID_Login": ID_Login, "ID_Grant": ID_Grant})

    # Smazat částku na osoboden
    def GrantAmountDelete(self, ID_Login, ID):
        return self._client.service.GrantAmountDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail částky na osoboden
    def GrantAmountDetail(self, ID_Login, ID):
        return self._client.service.GrantAmountDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit částku na osoboden
    def GrantAmountInsert(self, ID_Login, ID, ID_Grant, ID_EventEducationType, Amount, Year, MaximumCostsRatio, EventEducationType=None, Note=None, GrantConditions=None):
        return self._client.service.GrantAmountInsert({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_EventEducationType": ID_EventEducationType, "Amount": Amount, "Year": Year, "MaximumCostsRatio": MaximumCostsRatio, "EventEducationType": EventEducationType, "Note": Note, "GrantConditions": GrantConditions})

    # Upravit částku na osoboden
    def GrantAmountUpdate(self, ID_Login, ID, ID_Grant, ID_EventEducationType, Amount, Year, MaximumCostsRatio, EventEducationType=None, Note=None, GrantConditions=None):
        return self._client.service.GrantAmountUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_EventEducationType": ID_EventEducationType, "Amount": Amount, "Year": Year, "MaximumCostsRatio": MaximumCostsRatio, "EventEducationType": EventEducationType, "Note": Note, "GrantConditions": GrantConditions})

    # Načíst seznam příloh žádosti o dotaci
    def GrantAttachmentAll(self, ID_Login, ID_Grant, ID, ID_User, IsReal, ID_FileType=None, ID_AttachmentType=None):
        return self._client.service.GrantAttachmentAll({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID": ID, "ID_User": ID_User, "IsReal": IsReal, "ID_FileType": ID_FileType, "ID_AttachmentType": ID_AttachmentType})

    # Smazat přílohu žádosti o dotaci
    def GrantAttachmentDelete(self, ID_Login, ID):
        return self._client.service.GrantAttachmentDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail přílohy žádosti o dotaci
    def GrantAttachmentDetail(self, ID_Login, ID, LoadBackup):
        return self._client.service.GrantAttachmentDetail({"ID_Login": ID_Login, "ID": ID, "LoadBackup": LoadBackup})

    # Založit přílohu žádosti o dotaci
    def GrantAttachmentInsert(self, ID_Login, ID, IsReal, ID_Grant, ID_User, ID_Person, Date, Size, ID_TempFile, ID_GrantAttachment, IsAttached, IsCentralInsurance, IsDeposited, DepositYear, ID_Document, ID_DocumentBackup, Person=None, Description=None, FileName=None, ID_FileType=None, FileType=None, Extension=None, Hash=None, FileNameExtension=None, TempFile=None, IconPath=None, ID_AttachmentType=None, AttachmentType=None, BackupFileName=None, BackupExtension=None, ID_FileTypeBackup=None, BackupFileType=None, BackupIconPath=None, Note=None, Code=None, ID_GrantType=None, GrantType=None, Help=None, DisplayName=None):
        return self._client.service.GrantAttachmentInsert({"ID_Login": ID_Login, "ID": ID, "IsReal": IsReal, "ID_Grant": ID_Grant, "ID_User": ID_User, "ID_Person": ID_Person, "Date": Date, "Size": Size, "ID_TempFile": ID_TempFile, "ID_GrantAttachment": ID_GrantAttachment, "IsAttached": IsAttached, "IsCentralInsurance": IsCentralInsurance, "IsDeposited": IsDeposited, "DepositYear": DepositYear, "ID_Document": ID_Document, "ID_DocumentBackup": ID_DocumentBackup, "Person": Person, "Description": Description, "FileName": FileName, "ID_FileType": ID_FileType, "FileType": FileType, "Extension": Extension, "Hash": Hash, "FileNameExtension": FileNameExtension, "TempFile": TempFile, "IconPath": IconPath, "ID_AttachmentType": ID_AttachmentType, "AttachmentType": AttachmentType, "BackupFileName": BackupFileName, "BackupExtension": BackupExtension, "ID_FileTypeBackup": ID_FileTypeBackup, "BackupFileType": BackupFileType, "BackupIconPath": BackupIconPath, "Note": Note, "Code": Code, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Help": Help, "DisplayName": DisplayName})

    # Upravit přílohu žádosti o dotaci
    def GrantAttachmentUpdate(self, ID_Login, ID, IsReal, ID_Grant, ID_User, ID_Person, Date, Size, ID_TempFile, ID_GrantAttachment, IsAttached, IsCentralInsurance, IsDeposited, DepositYear, ID_Document, ID_DocumentBackup, Person=None, Description=None, FileName=None, ID_FileType=None, FileType=None, Extension=None, Hash=None, FileNameExtension=None, TempFile=None, IconPath=None, ID_AttachmentType=None, AttachmentType=None, BackupFileName=None, BackupExtension=None, ID_FileTypeBackup=None, BackupFileType=None, BackupIconPath=None, Note=None, Code=None, ID_GrantType=None, GrantType=None, Help=None, DisplayName=None):
        return self._client.service.GrantAttachmentUpdate({"ID_Login": ID_Login, "ID": ID, "IsReal": IsReal, "ID_Grant": ID_Grant, "ID_User": ID_User, "ID_Person": ID_Person, "Date": Date, "Size": Size, "ID_TempFile": ID_TempFile, "ID_GrantAttachment": ID_GrantAttachment, "IsAttached": IsAttached, "IsCentralInsurance": IsCentralInsurance, "IsDeposited": IsDeposited, "DepositYear": DepositYear, "ID_Document": ID_Document, "ID_DocumentBackup": ID_DocumentBackup, "Person": Person, "Description": Description, "FileName": FileName, "ID_FileType": ID_FileType, "FileType": FileType, "Extension": Extension, "Hash": Hash, "FileNameExtension": FileNameExtension, "TempFile": TempFile, "IconPath": IconPath, "ID_AttachmentType": ID_AttachmentType, "AttachmentType": AttachmentType, "BackupFileName": BackupFileName, "BackupExtension": BackupExtension, "ID_FileTypeBackup": ID_FileTypeBackup, "BackupFileType": BackupFileType, "BackupIconPath": BackupIconPath, "Note": Note, "Code": Code, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Help": Help, "DisplayName": DisplayName})

    # Načíst seznam účetních dokladů
    def GrantCostEvidenceAllGrant(self, ID_Login, ID, ID_Grant, Year, DisplayName=None):
        return self._client.service.GrantCostEvidenceAllGrant({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "Year": Year, "DisplayName": DisplayName})

    # Smazat účetní doklad
    def GrantCostEvidenceDelete(self, ID_Login, ID):
        return self._client.service.GrantCostEvidenceDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail účetního dokladu
    def GrantCostEvidenceDetail(self, ID_Login, ID, LoadFile):
        return self._client.service.GrantCostEvidenceDetail({"ID_Login": ID_Login, "ID": ID, "LoadFile": LoadFile})

    # Založit účetní doklad
    def GrantCostEvidenceInsert(self, ID_Login, ID, Amount, GrantAmount, ID_Grant, EvidenceDate, ID_TempFile, DeleteScan, Year, ID_Document, DisplayName=None, Description=None, EvidenceExtension=None, Note=None, EvidenceFile=None):
        return self._client.service.GrantCostEvidenceInsert({"ID_Login": ID_Login, "ID": ID, "Amount": Amount, "GrantAmount": GrantAmount, "ID_Grant": ID_Grant, "EvidenceDate": EvidenceDate, "ID_TempFile": ID_TempFile, "DeleteScan": DeleteScan, "Year": Year, "ID_Document": ID_Document, "DisplayName": DisplayName, "Description": Description, "EvidenceExtension": EvidenceExtension, "Note": Note, "EvidenceFile": EvidenceFile})

    # Upravit účetní doklad
    def GrantCostEvidenceUpdate(self, ID_Login, ID, Amount, GrantAmount, ID_Grant, EvidenceDate, ID_TempFile, DeleteScan, Year, ID_Document, DisplayName=None, Description=None, EvidenceExtension=None, Note=None, EvidenceFile=None):
        return self._client.service.GrantCostEvidenceUpdate({"ID_Login": ID_Login, "ID": ID, "Amount": Amount, "GrantAmount": GrantAmount, "ID_Grant": ID_Grant, "EvidenceDate": EvidenceDate, "ID_TempFile": ID_TempFile, "DeleteScan": DeleteScan, "Year": Year, "ID_Document": ID_Document, "DisplayName": DisplayName, "Description": Description, "EvidenceExtension": EvidenceExtension, "Note": Note, "EvidenceFile": EvidenceFile})

    # Načíst všechna potvrzená rozhodnutí o přidělení dotací
    def GrantDecisionAllConfirmed(self, ID_Login, Year, DateFrom, DateTo, AmountMin, AmountMax, ID_GrantType=None, Unit=None, UnitRegistrationNumber=None):
        return self._client.service.GrantDecisionAllConfirmed({"ID_Login": ID_Login, "Year": Year, "DateFrom": DateFrom, "DateTo": DateTo, "AmountMin": AmountMin, "AmountMax": AmountMax, "ID_GrantType": ID_GrantType, "Unit": Unit, "UnitRegistrationNumber": UnitRegistrationNumber})

    # Zaslat upomínky pro potvrzení rozhodnutí
    def GrantDecisionAllReminder(self, ID_Login):
        return self._client.service.GrantDecisionAllReminder({"ID_Login": ID_Login})

    # Načíst všechna rozhodnutí o přidělení dotací
    def GrantDecisionAll(self, ID_Login):
        return self._client.service.GrantDecisionAll({"ID_Login": ID_Login})

    # Smazat rozhodnutí o přidělení dotace
    def GrantDecisionDelete(self, ID_Login, ID):
        return self._client.service.GrantDecisionDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst data pro sestavu rozhodnutí o přidělení dotace
    def GrantDecisionDetailReport(self, ID_Login, ID):
        return self._client.service.GrantDecisionDetailReport({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail rozhodnutí o přidělení dotace
    def GrantDecisionDetail(self, ID_Login, ID):
        return self._client.service.GrantDecisionDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit rozhodnutí o přidělení dotace
    def GrantDecisionInsert(self, ID_Login, ID, ID_User, ID_Grant, Amount, MaxAmount, ValidFrom, ValidTo, LastUpdate, Revision, IsActive, ID_Provider, ID_Receiver, ID_Person, ID_Event, Year, ID_GrantDecisionState=None, GrantDecisionState=None, Note=None, Number=None, ProviderName=None, ProviderAddress=None, ProviderID=None, ProviderRegistrationNumber=None, ReceiverName=None, ReceiverAddress=None, ReceiverID=None, ReceiverRegistrationNumber=None, Person=None, EventName=None, ID_EventType=None, EventType=None):
        return self._client.service.GrantDecisionInsert({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "Amount": Amount, "MaxAmount": MaxAmount, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "LastUpdate": LastUpdate, "Revision": Revision, "IsActive": IsActive, "ID_Provider": ID_Provider, "ID_Receiver": ID_Receiver, "ID_Person": ID_Person, "ID_Event": ID_Event, "Year": Year, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "Note": Note, "Number": Number, "ProviderName": ProviderName, "ProviderAddress": ProviderAddress, "ProviderID": ProviderID, "ProviderRegistrationNumber": ProviderRegistrationNumber, "ReceiverName": ReceiverName, "ReceiverAddress": ReceiverAddress, "ReceiverID": ReceiverID, "ReceiverRegistrationNumber": ReceiverRegistrationNumber, "Person": Person, "EventName": EventName, "ID_EventType": ID_EventType, "EventType": EventType})

    # Upravit rozhodnutí o přidělení dotace
    def GrantDecisionUpdate(self, ID_Login, ID, ID_User, ID_Grant, Amount, MaxAmount, ValidFrom, ValidTo, LastUpdate, Revision, IsActive, ID_Provider, ID_Receiver, ID_Person, ID_Event, Year, ID_GrantDecisionState=None, GrantDecisionState=None, Note=None, Number=None, ProviderName=None, ProviderAddress=None, ProviderID=None, ProviderRegistrationNumber=None, ReceiverName=None, ReceiverAddress=None, ReceiverID=None, ReceiverRegistrationNumber=None, Person=None, EventName=None, ID_EventType=None, EventType=None):
        return self._client.service.GrantDecisionUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "Amount": Amount, "MaxAmount": MaxAmount, "ValidFrom": ValidFrom, "ValidTo": ValidTo, "LastUpdate": LastUpdate, "Revision": Revision, "IsActive": IsActive, "ID_Provider": ID_Provider, "ID_Receiver": ID_Receiver, "ID_Person": ID_Person, "ID_Event": ID_Event, "Year": Year, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "Note": Note, "Number": Number, "ProviderName": ProviderName, "ProviderAddress": ProviderAddress, "ProviderID": ProviderID, "ProviderRegistrationNumber": ProviderRegistrationNumber, "ReceiverName": ReceiverName, "ReceiverAddress": ReceiverAddress, "ReceiverID": ReceiverID, "ReceiverRegistrationNumber": ReceiverRegistrationNumber, "Person": Person, "EventName": EventName, "ID_EventType": ID_EventType, "EventType": EventType})

    # Založit dílčí akci pro neorg. mládež
    def GrantEventInsert(self, ID_Login, ID, ID_User, ID_Grant, Count, Days, ChildrenCount, YoungCount, OtherCount, PersonDays, IsEstimation, IsCustomDays, DisplayName=None, Description=None, Place=None):
        return self._client.service.GrantEventInsert({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "Count": Count, "Days": Days, "ChildrenCount": ChildrenCount, "YoungCount": YoungCount, "OtherCount": OtherCount, "PersonDays": PersonDays, "IsEstimation": IsEstimation, "IsCustomDays": IsCustomDays, "DisplayName": DisplayName, "Description": Description, "Place": Place})

    # Upravit dílčí akci pro neorg. mládež
    def GrantEventUpdate(self, ID_Login, ID, ID_User, ID_Grant, Count, Days, ChildrenCount, YoungCount, OtherCount, PersonDays, IsEstimation, IsCustomDays, DisplayName=None, Description=None, Place=None):
        return self._client.service.GrantEventUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "Count": Count, "Days": Days, "ChildrenCount": ChildrenCount, "YoungCount": YoungCount, "OtherCount": OtherCount, "PersonDays": PersonDays, "IsEstimation": IsEstimation, "IsCustomDays": IsCustomDays, "DisplayName": DisplayName, "Description": Description, "Place": Place})

    # Založit žádost o dotaci
    def GrantInsertCreateRemaining(self, ID_Login, ID_EventEducation, ID_Event, ID_Unit, ID_EventEducationCourse):
        return self._client.service.GrantInsertCreateRemaining({"ID_Login": ID_Login, "ID_EventEducation": ID_EventEducation, "ID_Event": ID_Event, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse})

    # Načíst seznam dalších údajů v žádosti o dotaci
    def GrantOtherAll(self, ID_Login, ID_Application, ID_Grant):
        return self._client.service.GrantOtherAll({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID_Grant": ID_Grant})

    # Smazat další údaje v žádosti o dotaci
    def GrantOtherDelete(self, ID_Login, ID):
        return self._client.service.GrantOtherDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail dalších údajů v žádosti o dotaci
    def GrantOtherDetail(self, ID_Login, ID_Grant):
        return self._client.service.GrantOtherDetail({"ID_Login": ID_Login, "ID_Grant": ID_Grant})

    # Založit další údaje v žádosti o dotaci
    def GrantOtherInsert(self, ID_Login, ID_Application, ID, ID_Grant, ID_RealtyCollection, OwnershipListNumber, ID_GrantRealtyCollection, Goal=None, Description=None, TargetGroup=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, City=None):
        return self._client.service.GrantOtherInsert({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "ID_Grant": ID_Grant, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "Goal": Goal, "Description": Description, "TargetGroup": TargetGroup, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "City": City})

    # Upravit další údaje v žádosti o dotaci
    def GrantOtherUpdate(self, ID_Login, ID_Application, ID, ID_Grant, ID_RealtyCollection, OwnershipListNumber, ID_GrantRealtyCollection, Goal=None, Description=None, TargetGroup=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, City=None):
        return self._client.service.GrantOtherUpdate({"ID_Login": ID_Login, "ID_Application": ID_Application, "ID": ID, "ID_Grant": ID_Grant, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "Goal": Goal, "Description": Description, "TargetGroup": TargetGroup, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "City": City})

    # Načíst seznam projektů žádosti o dotaci
    def GrantProjectAll(self, ID_Login, ID_Grant, ID, ID_User, IsUseShorDescription, DisplayName=None, ID_DateType=None):
        return self._client.service.GrantProjectAll({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID": ID, "ID_User": ID_User, "IsUseShorDescription": IsUseShorDescription, "DisplayName": DisplayName, "ID_DateType": ID_DateType})

    # Smazat projekt žádosti o dotaci
    def GrantProjectDelete(self, ID_Login, ID):
        return self._client.service.GrantProjectDelete({"ID_Login": ID_Login, "ID": ID})

    # Načíst detail projektu žádosti o dotaci
    def GrantProjectDetail(self, ID_Login, ID):
        return self._client.service.GrantProjectDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit projekt žádosti o dotaci
    def GrantProjectInsert(self, ID_Login, ID, ID_User, ID_Grant, From, To, IsActive, IsGrantWide, DisplayName=None, Description=None, ID_DateType=None, DateType=None, Place=None, Note=None):
        return self._client.service.GrantProjectInsert({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "From": From, "To": To, "IsActive": IsActive, "IsGrantWide": IsGrantWide, "DisplayName": DisplayName, "Description": Description, "ID_DateType": ID_DateType, "DateType": DateType, "Place": Place, "Note": Note})

    # Načíst seznam účastí v projektu žádosti o dotaci
    def GrantProjectParticipationAll(self, ID_Login, ID_GrantProject, ID_GrantType=None):
        return self._client.service.GrantProjectParticipationAll({"ID_Login": ID_Login, "ID_GrantProject": ID_GrantProject, "ID_GrantType": ID_GrantType})

    # Načíst seznam účastí v projektu žádosti o dotaci
    def GrantProjectParticipationAllGrant(self, ID_Login, ID_Grant, ID_GrantType=None):
        return self._client.service.GrantProjectParticipationAllGrant({"ID_Login": ID_Login, "ID_Grant": ID_Grant, "ID_GrantType": ID_GrantType})

    # Smazat účast v projektu žádosti o dotaci
    def GrantProjectParticipationDelete(self, ID_Login, ID):
        return self._client.service.GrantProjectParticipationDelete({"ID_Login": ID_Login, "ID": ID})

    # Založit účast v projektu žádosti o dotaci
    def GrantProjectParticipationInsert(self, ID_Login, ID, ID_GrantProject, Count, PersonDays, GrantProject=None, ID_ProjectParticipationCategory=None, ProjectParticipationCategory=None):
        return self._client.service.GrantProjectParticipationInsert({"ID_Login": ID_Login, "ID": ID, "ID_GrantProject": ID_GrantProject, "Count": Count, "PersonDays": PersonDays, "GrantProject": GrantProject, "ID_ProjectParticipationCategory": ID_ProjectParticipationCategory, "ProjectParticipationCategory": ProjectParticipationCategory})

    # Upravit účast v projektu žádosti o dotaci
    def GrantProjectParticipationUpdate(self, ID_Login, ID, ID_GrantProject, Count, PersonDays, GrantProject=None, ID_ProjectParticipationCategory=None, ProjectParticipationCategory=None):
        return self._client.service.GrantProjectParticipationUpdate({"ID_Login": ID_Login, "ID": ID, "ID_GrantProject": ID_GrantProject, "Count": Count, "PersonDays": PersonDays, "GrantProject": GrantProject, "ID_ProjectParticipationCategory": ID_ProjectParticipationCategory, "ProjectParticipationCategory": ProjectParticipationCategory})

    # Upravit projekt žádosti o dotaci
    def GrantProjectUpdate(self, ID_Login, ID, ID_User, ID_Grant, From, To, IsActive, IsGrantWide, DisplayName=None, Description=None, ID_DateType=None, DateType=None, Place=None, Note=None):
        return self._client.service.GrantProjectUpdate({"ID_Login": ID_Login, "ID": ID, "ID_User": ID_User, "ID_Grant": ID_Grant, "From": From, "To": To, "IsActive": IsActive, "IsGrantWide": IsGrantWide, "DisplayName": DisplayName, "Description": Description, "ID_DateType": ID_DateType, "DateType": DateType, "Place": Place, "Note": Note})

    # No documentation
    def GrantRealtyCollectionAll(self, ID_Login, ID, ID_Grant, ID_RealtyCollection, OwnershipListNumber, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, City=None):
        return self._client.service.GrantRealtyCollectionAll({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "City": City})

    # No documentation
    def GrantRealtyCollectionDetail(self, ID_Login, ID, ID_Grant, ID_RealtyCollection, OwnershipListNumber, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, City=None):
        return self._client.service.GrantRealtyCollectionDetail({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "City": City})

    # No documentation
    def GrantRealtyCollectionInsert(self, ID_Login, ID, ID_Grant, ID_RealtyCollection, OwnershipListNumber, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, RealtyCollection=None):
        return self._client.service.GrantRealtyCollectionInsert({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "RealtyCollection": RealtyCollection})

    # Založit RealtyCollectionUpdate
    def GrantRealtyCollectionUpdate(self, ID_Login, ID, ID_Grant, ID_RealtyCollection, OwnershipListNumber, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, City=None):
        return self._client.service.GrantRealtyCollectionUpdate({"ID_Login": ID_Login, "ID": ID, "ID_Grant": ID_Grant, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "City": City})

    # Načíst seznam doplňujících textů typu dotace
    def GrantTypeTextAll(self, ID_Login, ID, ID_GrantType=None, DisplayName=None, ID_GrantTypeTextCategory=None):
        return self._client.service.GrantTypeTextAll({"ID_Login": ID_Login, "ID": ID, "ID_GrantType": ID_GrantType, "DisplayName": DisplayName, "ID_GrantTypeTextCategory": ID_GrantTypeTextCategory})

    # Načíst seznam kategorií doplňujícího textu
    def GrantTypeTextCategoryAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.GrantTypeTextCategoryAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst detail kategorie doplňujícího textu
    def GrantTypeTextCategoryDetail(self, ID_Login, ID=None):
        return self._client.service.GrantTypeTextCategoryDetail({"ID_Login": ID_Login, "ID": ID})

    # Smazat doplňující text typu dotace
    def GrantTypeTextDelete(self, ID_Login, ID, IsActive, Order, IsNumbered, ForChange, ForRevoke, ForFirstRevoke, ID_GrantType=None, GrantType=None, DisplayName=None, Text=None, Note=None, ID_GrantTypeTextCategory=None, GrantTypeTextCategory=None, TextWithoutLines=None):
        return self._client.service.GrantTypeTextDelete({"ID_Login": ID_Login, "ID": ID, "IsActive": IsActive, "Order": Order, "IsNumbered": IsNumbered, "ForChange": ForChange, "ForRevoke": ForRevoke, "ForFirstRevoke": ForFirstRevoke, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "DisplayName": DisplayName, "Text": Text, "Note": Note, "ID_GrantTypeTextCategory": ID_GrantTypeTextCategory, "GrantTypeTextCategory": GrantTypeTextCategory, "TextWithoutLines": TextWithoutLines})

    # Načíst detail doplňujícího textu typu dotace
    def GrantTypeTextDetail(self, ID_Login, ID):
        return self._client.service.GrantTypeTextDetail({"ID_Login": ID_Login, "ID": ID})

    # Založit doplňující text typu dotace
    def GrantTypeTextInsert(self, ID_Login, ID, IsActive, Order, IsNumbered, ForChange, ForRevoke, ForFirstRevoke, ID_GrantType=None, GrantType=None, DisplayName=None, Text=None, Note=None, ID_GrantTypeTextCategory=None, GrantTypeTextCategory=None, TextWithoutLines=None):
        return self._client.service.GrantTypeTextInsert({"ID_Login": ID_Login, "ID": ID, "IsActive": IsActive, "Order": Order, "IsNumbered": IsNumbered, "ForChange": ForChange, "ForRevoke": ForRevoke, "ForFirstRevoke": ForFirstRevoke, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "DisplayName": DisplayName, "Text": Text, "Note": Note, "ID_GrantTypeTextCategory": ID_GrantTypeTextCategory, "GrantTypeTextCategory": GrantTypeTextCategory, "TextWithoutLines": TextWithoutLines})

    # Změnit pořadí doplňujícího textu typu dotace
    def GrantTypeTextUpdateChangeOrder(self, ID_Login, ID, Direction):
        return self._client.service.GrantTypeTextUpdateChangeOrder({"ID_Login": ID_Login, "ID": ID, "Direction": Direction})

    # Upravit doplňující text typu dotace
    def GrantTypeTextUpdate(self, ID_Login, ID, IsActive, Order, IsNumbered, ForChange, ForRevoke, ForFirstRevoke, ID_GrantType=None, GrantType=None, DisplayName=None, Text=None, Note=None, ID_GrantTypeTextCategory=None, GrantTypeTextCategory=None, TextWithoutLines=None):
        return self._client.service.GrantTypeTextUpdate({"ID_Login": ID_Login, "ID": ID, "IsActive": IsActive, "Order": Order, "IsNumbered": IsNumbered, "ForChange": ForChange, "ForRevoke": ForRevoke, "ForFirstRevoke": ForFirstRevoke, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "DisplayName": DisplayName, "Text": Text, "Note": Note, "ID_GrantTypeTextCategory": ID_GrantTypeTextCategory, "GrantTypeTextCategory": GrantTypeTextCategory, "TextWithoutLines": TextWithoutLines})

    # Načíst seznam proměnných doplňujícího textu dotace
    def GrantTypeTextVariableAll(self, ID_Login, ID=None, DisplayName=None):
        return self._client.service.GrantTypeTextVariableAll({"ID_Login": ID_Login, "ID": ID, "DisplayName": DisplayName})

    # Načíst detail proměnné doplňujícího textu dotace
    def GrantTypeTextVariableDetail(self, ID_Login, ID=None):
        return self._client.service.GrantTypeTextVariableDetail({"ID_Login": ID_Login, "ID": ID})

    # Schválit vyúčtování žádosti o dotaci
    def GrantUpdateAllGrantSummaryApprove(self, grantAllHeadquartersInput=None):
        return self._client.service.GrantUpdateAllGrantSummaryApprove({"grantAllHeadquartersInput": grantAllHeadquartersInput})

    # Odevzdat vyúčtování žádosti o dotaci
    def GrantUpdateAllGrantSummary(self, grantAllHeadquartersInput=None):
        return self._client.service.GrantUpdateAllGrantSummary({"grantAllHeadquartersInput": grantAllHeadquartersInput})

    # Aktualizace záznamu pro headquarters účetníctví
    def GrantUpdateAccount(self, ID_Login, ID, Amount, AmountMaxReal, Costs, AmountRealRatio, GrantAdvanceAmount, AmountReal, GrantAdvanceRemainingPay, GrantAdvanceSupplement, GrantAdvanceSupplementDate, AmountRealDate, GrantAdvanceAmountTotal, HasGrantAdvanceAmount, ID_GrantState=None, GrantState=None, Code=None, DisplayName=None, ID_GrantType=None, GrantType=None, GrantAdvanceSupplementMoney=None, GrantAdvanceState=None, GrantAdvanceNote=None, ID_EventEducation=None):
        return self._client.service.GrantUpdateAccount({"ID_Login": ID_Login, "ID": ID, "Amount": Amount, "AmountMaxReal": AmountMaxReal, "Costs": Costs, "AmountRealRatio": AmountRealRatio, "GrantAdvanceAmount": GrantAdvanceAmount, "AmountReal": AmountReal, "GrantAdvanceRemainingPay": GrantAdvanceRemainingPay, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "AmountRealDate": AmountRealDate, "GrantAdvanceAmountTotal": GrantAdvanceAmountTotal, "HasGrantAdvanceAmount": HasGrantAdvanceAmount, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "Code": Code, "DisplayName": DisplayName, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "GrantAdvanceSupplementMoney": GrantAdvanceSupplementMoney, "GrantAdvanceState": GrantAdvanceState, "GrantAdvanceNote": GrantAdvanceNote, "ID_EventEducation": ID_EventEducation})

    # Upravit poznámku projektu žádosti o dotaci
    def GrantUpdateProjectNote(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateProjectNote({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Uzavře žádost o dotaci
    def GrantUpdateOpen(self, ID_Login, ID):
        return self._client.service.GrantUpdateOpen({"ID_Login": ID_Login, "ID": ID})

    # Uzavře žádost o dotaci
    def GrantUpdateClose(self, ID_Login, ID):
        return self._client.service.GrantUpdateClose({"ID_Login": ID_Login, "ID": ID})

    # Odevzdat vyúčtování žádosti o dotaci
    def GrantUpdateHeadquartersNote(self, ID_Login, ID, Year, ID_GrantType=None, HeadquartersNote=None):
        return self._client.service.GrantUpdateHeadquartersNote({"ID_Login": ID_Login, "ID": ID, "Year": Year, "ID_GrantType": ID_GrantType, "HeadquartersNote": HeadquartersNote})

    # Odevzdat vyúčtování žádosti o dotaci
    def GrantUpdateLeaderNote(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateLeaderNote({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Upravit poznámku k závěrečnému rozpočtu
    def GrantUpdateFinalStatementNote(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateFinalStatementNote({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Upravit poznámku k rozpočtu
    def GrantUpdateStatementNote(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateStatementNote({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Upravit vyhodnocení projektu u žádosti o dotaci
    def GrantUpdateEvaluation(self, ID_Login, ID, Evaluation=None):
        return self._client.service.GrantUpdateEvaluation({"ID_Login": ID_Login, "ID": ID, "Evaluation": Evaluation})

    # Zrušit žádost o dotaci
    def GrantUpdateCanceled(self, ID_Login, ID, Note=None):
        return self._client.service.GrantUpdateCanceled({"ID_Login": ID_Login, "ID": ID, "Note": Note})

    # Žádost o doplnění žádosti o dotaci
    def GrantUpdateComplement(self, ID_Login, ID, Note=None):
        return self._client.service.GrantUpdateComplement({"ID_Login": ID_Login, "ID": ID, "Note": Note})

    # Odevzdat vyúčtování žádosti o dotaci
    def GrantUpdateBillSubmit(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateBillSubmit({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Potvrdit vyúčtování žádosti o dotaci
    def GrantUpdateBillConfirm(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateBillConfirm({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Zrušit odevzdání vyúčtování žádosti o dotaci
    def GrantUpdateBillSubmitCancel(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateBillSubmitCancel({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Zrušit potvrzení vyúčtování žádosti o dotaci
    def GrantUpdateBillConfirmCancel(self, ID_Login, ID, ID_Event, ID_EventEducation, Sequence, ID_Unit, ID_EventEducationCourse, ID_GrantDecision, IsApproved, AdvanceSentAmount, Submitted, ID_PersonSubmitter, Confirmed, ID_PersonConfirmer, ID_PersonCommitte, Year, ID_PersonLeader, ID_PersonEconomist, ID_PersonResponsible, HasProject, ID_GrantProject, TermFrom, TermTo, ID_GrantRealtyCollection, ID_RealtyCollection, OwnershipListNumber, ID_PersonCommitteNote, RemainingPay, Amount, AmountMax, AmountMaxReal, AmountMaxRatio, AmountMaxRealRatio, AmountMaxValid, AmountMaxRealValid, AmountRequested, AmountReal, Costs, CostsReal, Revenue, RevenueReal, RatioMaxSettings, RatioMaxGrant, Ratio, RatioReal, MaximumCostsRatio, WarningAmountMaxRatio, WarningAmountMax, WarningProfit, WarningProfitNonZero, WarningAmountRatio, WarningAmountMaxRealRatio, WarningAmountRealMax, WarningProfitReal, WarningProfitRealNonZero, IsEstimation, RealRequestedGrant, IsLocked, IsEstimationLocked, CommitteeNoteDate, IsVisibleMaxAmount, RealizationFrom, RealizationTo, ID_PersonEventLeader, AmountGrant, AmountStatement, Agree, GrantAdvanceSupplement, GrantAdvanceAmount, GrantAdvanceSupplementDate, GrantDecisionApproved, GrantCostEvidenceTotal, ID_GrantProjectUniversal, Event=None, ID_GrantType=None, GrantType=None, Code=None, ID_GrantAdvanceType=None, GrantAdvanceType=None, CommitteeNote=None, Unit=None, RegistrationNumber=None, UnitFullName=None, GrantAdvanceNote=None, EventEducationCourse=None, ID_GrantState=None, GrantState=None, ID_GrantDecisionState=None, GrantDecisionState=None, DenialReason=None, PersonSubmitter=None, PersonSubmitterContact=None, PersonConfirmer=None, CivilNameConfirmer=None, PersonConfirmerContact=None, PersonCommitte=None, CivilNameCommitte=None, PersonCommitteContact=None, ChangeNote=None, SpecificSymbol=None, Evaluation=None, EvaluationDecoded=None, StatementNote=None, ProjectName=None, PersonLeader=None, CivilNameLeader=None, NoteLeader=None, IdentificationCodeLeader=None, PersonEconomist=None, NoteEconomist=None, IdentificationCodeEconomist=None, PersonResponsible=None, NoteResponsible=None, IdentificationCodeResponsible=None, ContactPhone=None, ContactEmail=None, ProjectCharacteristic=None, ContactPhoneEconomist=None, ContactEmailEconomist=None, FinalStatementNote=None, GrantProjectNote=None, Place=None, ContactPhoneResponsible=None, ContactEmailResponsible=None, RealtyCollection=None, CadastralArea=None, BuildingOwner=None, ParcelNumbers=None, ParcelOwner=None, LeaderNote=None, PersonEventLeader=None, CivilNameEventLeader=None, EventEducation=None, GrantConditions=None):
        return self._client.service.GrantUpdateBillConfirmCancel({"ID_Login": ID_Login, "ID": ID, "ID_Event": ID_Event, "ID_EventEducation": ID_EventEducation, "Sequence": Sequence, "ID_Unit": ID_Unit, "ID_EventEducationCourse": ID_EventEducationCourse, "ID_GrantDecision": ID_GrantDecision, "IsApproved": IsApproved, "AdvanceSentAmount": AdvanceSentAmount, "Submitted": Submitted, "ID_PersonSubmitter": ID_PersonSubmitter, "Confirmed": Confirmed, "ID_PersonConfirmer": ID_PersonConfirmer, "ID_PersonCommitte": ID_PersonCommitte, "Year": Year, "ID_PersonLeader": ID_PersonLeader, "ID_PersonEconomist": ID_PersonEconomist, "ID_PersonResponsible": ID_PersonResponsible, "HasProject": HasProject, "ID_GrantProject": ID_GrantProject, "TermFrom": TermFrom, "TermTo": TermTo, "ID_GrantRealtyCollection": ID_GrantRealtyCollection, "ID_RealtyCollection": ID_RealtyCollection, "OwnershipListNumber": OwnershipListNumber, "ID_PersonCommitteNote": ID_PersonCommitteNote, "RemainingPay": RemainingPay, "Amount": Amount, "AmountMax": AmountMax, "AmountMaxReal": AmountMaxReal, "AmountMaxRatio": AmountMaxRatio, "AmountMaxRealRatio": AmountMaxRealRatio, "AmountMaxValid": AmountMaxValid, "AmountMaxRealValid": AmountMaxRealValid, "AmountRequested": AmountRequested, "AmountReal": AmountReal, "Costs": Costs, "CostsReal": CostsReal, "Revenue": Revenue, "RevenueReal": RevenueReal, "RatioMaxSettings": RatioMaxSettings, "RatioMaxGrant": RatioMaxGrant, "Ratio": Ratio, "RatioReal": RatioReal, "MaximumCostsRatio": MaximumCostsRatio, "WarningAmountMaxRatio": WarningAmountMaxRatio, "WarningAmountMax": WarningAmountMax, "WarningProfit": WarningProfit, "WarningProfitNonZero": WarningProfitNonZero, "WarningAmountRatio": WarningAmountRatio, "WarningAmountMaxRealRatio": WarningAmountMaxRealRatio, "WarningAmountRealMax": WarningAmountRealMax, "WarningProfitReal": WarningProfitReal, "WarningProfitRealNonZero": WarningProfitRealNonZero, "IsEstimation": IsEstimation, "RealRequestedGrant": RealRequestedGrant, "IsLocked": IsLocked, "IsEstimationLocked": IsEstimationLocked, "CommitteeNoteDate": CommitteeNoteDate, "IsVisibleMaxAmount": IsVisibleMaxAmount, "RealizationFrom": RealizationFrom, "RealizationTo": RealizationTo, "ID_PersonEventLeader": ID_PersonEventLeader, "AmountGrant": AmountGrant, "AmountStatement": AmountStatement, "Agree": Agree, "GrantAdvanceSupplement": GrantAdvanceSupplement, "GrantAdvanceAmount": GrantAdvanceAmount, "GrantAdvanceSupplementDate": GrantAdvanceSupplementDate, "GrantDecisionApproved": GrantDecisionApproved, "GrantCostEvidenceTotal": GrantCostEvidenceTotal, "ID_GrantProjectUniversal": ID_GrantProjectUniversal, "Event": Event, "ID_GrantType": ID_GrantType, "GrantType": GrantType, "Code": Code, "ID_GrantAdvanceType": ID_GrantAdvanceType, "GrantAdvanceType": GrantAdvanceType, "CommitteeNote": CommitteeNote, "Unit": Unit, "RegistrationNumber": RegistrationNumber, "UnitFullName": UnitFullName, "GrantAdvanceNote": GrantAdvanceNote, "EventEducationCourse": EventEducationCourse, "ID_GrantState": ID_GrantState, "GrantState": GrantState, "ID_GrantDecisionState": ID_GrantDecisionState, "GrantDecisionState": GrantDecisionState, "DenialReason": DenialReason, "PersonSubmitter": PersonSubmitter, "PersonSubmitterContact": PersonSubmitterContact, "PersonConfirmer": PersonConfirmer, "CivilNameConfirmer": CivilNameConfirmer, "PersonConfirmerContact": PersonConfirmerContact, "PersonCommitte": PersonCommitte, "CivilNameCommitte": CivilNameCommitte, "PersonCommitteContact": PersonCommitteContact, "ChangeNote": ChangeNote, "SpecificSymbol": SpecificSymbol, "Evaluation": Evaluation, "EvaluationDecoded": EvaluationDecoded, "StatementNote": StatementNote, "ProjectName": ProjectName, "PersonLeader": PersonLeader, "CivilNameLeader": CivilNameLeader, "NoteLeader": NoteLeader, "IdentificationCodeLeader": IdentificationCodeLeader, "PersonEconomist": PersonEconomist, "NoteEconomist": NoteEconomist, "IdentificationCodeEconomist": IdentificationCodeEconomist, "PersonResponsible": PersonResponsible, "NoteResponsible": NoteResponsible, "IdentificationCodeResponsible": IdentificationCodeResponsible, "ContactPhone": ContactPhone, "ContactEmail": ContactEmail, "ProjectCharacteristic": ProjectCharacteristic, "ContactPhoneEconomist": ContactPhoneEconomist, "ContactEmailEconomist": ContactEmailEconomist, "FinalStatementNote": FinalStatementNote, "GrantProjectNote": GrantProjectNote, "Place": Place, "ContactPhoneResponsible": ContactPhoneResponsible, "ContactEmailResponsible": ContactEmailResponsible, "RealtyCollection": RealtyCollection, "CadastralArea": CadastralArea, "BuildingOwner": BuildingOwner, "ParcelNumbers": ParcelNumbers, "ParcelOwner": ParcelOwner, "LeaderNote": LeaderNote, "PersonEventLeader": PersonEventLeader, "CivilNameEventLeader": CivilNameEventLeader, "EventEducation": EventEducation, "GrantConditions": GrantConditions})

    # Zrušení potvrzení žádosti o dotaci vedoucím OJ
    def GrantUpdateConfirmCancel(self, ID_Login, ID):
        return self._client.service.GrantUpdateConfirmCancel({"ID_Login": ID_Login, "ID": ID})

    # Potvrzení žádosti o dotaci vedoucím OJ
    def GrantUpdateConfirm(self, ID_Login, ID):
        return self._client.service.GrantUpdateConfirm({"ID_Login": ID_Login, "ID": ID})

    # Odmítnout žádost o dotaci
    def GrantUpdateDenied(self, ID_Login, ID, Note=None):
        return self._client.service.GrantUpdateDenied({"ID_Login": ID_Login, "ID": ID, "Note": Note})

    # Odmítnout schválení žádosti o dotaci
    def GrantUpdateDisapprove(self, ID_Login, ID, Note=None):
        return self._client.service.GrantUpdateDisapprove({"ID_Login": ID_Login, "ID": ID, "Note": Note})

    # Zrušit odevzdání žádosti o dotaci
    def GrantUpdateApplyCancel(self, ID_Login, ID):
        return self._client.service.GrantUpdateApplyCancel({"ID_Login": ID_Login, "ID": ID})

